#!/bin/sh
echo 'name: ghc-mtl
version: 1.0.1.2
id: ghc-mtl-1.0.1.2-567b75cd9019760c82fa5fc9316de2f1

license: BSD3
copyright:
maintainer: jcpetruzza@gmail.com
stability:
homepage: http://darcsden.com/jcpetruzza/ghc-mtl
package-url:
synopsis: An mtl compatible version of the Ghc-Api monads
          and monad-transformers.
description: Provides an '\''mtl'\'' compatible version of the '\''GhcT'\''
             monad-transformer defined in the '\''GHC-API'\'' since version
             6.10.1.
category: Development
author: Daniel Gorin
pkgpath: devel/hs-ghc-mtl
exposed: True
exposed-modules: Control.Monad.Ghc
hidden-modules:
trusted: False
import-dirs: /usr/local/lib/ghc/ghc-mtl-1.0.1.2
library-dirs: /usr/local/lib/ghc/ghc-mtl-1.0.1.2
hs-libraries: HSghc-mtl-1.0.1.2
extra-libraries:
extra-ghci-libraries:
include-dirs:
includes:
depends: MonadCatchIO-mtl-0.3.0.5-db87269a14c9e10c4e605bc41f9823f9
         base-4.6.0.1-d435272bc8de1d17f3a0aacfbd562dbe
         ghc-7.6.3-9809b0fefd2b7427f85e285fdfdf8d3e
         mtl-2.1.2-735d9c92b4f214d454fb5168bb1eb6ee
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/hs-ghc-mtl-1.0.1.2/html/ghc-mtl.haddock
haddock-html: /usr/local/share/doc/hs-ghc-mtl-1.0.1.2/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
